@@ -38,8 +38,8 @@ class AutoStartPage : public QWidget
     Q_OBJECT
 
 public:
-    explicit AutoStartPage(QWidget* parent = 0);
-    ~AutoStartPage();
+    explicit AutoStartPage(QWidget* parent = nullptr);
+    ~AutoStartPage() override;
 
 signals:
     void needRestart();
