@@ -37,6 +37,7 @@ static const QLatin1String leaveConfirmationKey("leave_confirmation");
 static const QLatin1String lockBeforePowerActionsKey("lock_screen_before_power_actions");
 static const QLatin1String powerActionsAfterLockDelayKey("power_actions_after_lock_delay");
 static const QLatin1String QtScaleKey("QT_SCALE_FACTOR");
+static const QLatin1String x11LockCommandKey("lock_command");
 static const QLatin1String GdkScaleKey("GDK_SCALE");
 static const QLatin1String openboxValue("openbox");
 
@@ -50,6 +51,7 @@ BasicSettings::BasicSettings(LXQt::Settings *settings, QWidget *parent) :
     connect(ui->findWmButton, &QPushButton::clicked, this, &BasicSettings::findWmButton_clicked);
     connect(ui->startButton,  &QPushButton::clicked, this, &BasicSettings::startButton_clicked);
     connect(ui->stopButton,   &QPushButton::clicked, this, &BasicSettings::stopButton_clicked);
+    connect(ui->findX11LockCommandButton, &QPushButton::clicked, this, &BasicSettings::findX11LockCommandButton_clicked);
     restoreSettings();
 
     ui->moduleView->setModel(m_moduleModel);
@@ -71,6 +73,9 @@ void BasicSettings::restoreSettings()
         knownWMs << wm.command;
     }
 
+    QStringList knownX11Locker;
+    knownX11Locker << QStringLiteral("i3lock") << QStringLiteral("kscreenlocker") << QStringLiteral("slock") << QStringLiteral("xsecurelock") << QStringLiteral("xlock");
+
     QString wm = m_settings->value(windowManagerKey, openboxValue).toString();
     SessionConfigWindow::handleCfgComboBox(ui->wmComboBox, knownWMs, wm);
     m_moduleModel->reset();
@@ -82,6 +87,11 @@ void BasicSettings::restoreSettings()
     m_settings->beginGroup(QL1S("Environment"));
     ui->scaleSpinBox->setValue(m_settings->value(QtScaleKey, 1.0).toDouble());
     m_settings->endGroup();
+
+    QString x11LockCommand = m_settings->value(x11LockCommandKey, QString()).toString();
+    SessionConfigWindow::handleCfgComboBox(ui->x11LockCommandComboBox, knownX11Locker, x11LockCommand);
+
+    ui->customLockBox->setChecked(!x11LockCommand.isEmpty());
 }
 
 void BasicSettings::save()
@@ -97,6 +107,8 @@ void BasicSettings::save()
     const bool lockBeforePowerActions = ui->lockBeforePowerActionsCheckBox->isChecked();
     const int powerAfterLockDelay = ui->powerAfterLockDelaySpinBox->value();
     const double scaleFactor = ui->scaleSpinBox->value();
+    const QString x11LockCommand = ui->customLockBox->isChecked() ? ui->x11LockCommandComboBox->currentText()
+                                                                  : QString();
 
     QMap<QString, AutostartItem> previousItems(AutostartItem::createItemMap());
     QMutableMapIterator<QString, AutostartItem> i(previousItems);
@@ -132,6 +144,15 @@ void BasicSettings::save()
         doRestart = true;
     }
 
+    if (x11LockCommand != m_settings->value(x11LockCommandKey, QString()).toString())
+    {
+        if (x11LockCommand.isEmpty())
+            m_settings->remove(x11LockCommandKey);
+        else
+            m_settings->setValue(x11LockCommandKey, x11LockCommand);
+        doRestart = true;
+    }
+
     bool scaleChanged = false;
     m_settings->beginGroup(QL1S("Environment"));
     if (scaleFactor != m_settings->value(QtScaleKey, 1.0).toDouble()
@@ -185,3 +206,8 @@ void BasicSettings::stopButton_clicked()
 {
     m_moduleModel->toggleModule(ui->moduleView->selectionModel()->currentIndex(), false);
 }
+
+void BasicSettings::findX11LockCommandButton_clicked()
+{
+    SessionConfigWindow::updateCfgComboBox(ui->x11LockCommandComboBox, tr("Select a screenlocker"));
+}
