@@ -65,42 +65,50 @@
 <context>
     <name>AutoStartPage</name>
     <message>
-        <location filename="../autostartpage.ui" line="17"/>
+        <location filename="../autostartpage.ui" line="51"/>
         <source>Delete</source>
         <translation>Gyawo</translation>
     </message>
     <message>
-        <location filename="../autostartpage.ui" line="24"/>
+        <location filename="../autostartpage.ui" line="37"/>
         <source>Add</source>
         <translation>Yongerawo</translation>
     </message>
     <message>
-        <location filename="../autostartpage.ui" line="31"/>
+        <location filename="../autostartpage.ui" line="44"/>
         <source>Edit</source>
         <translation>Kyusa</translation>
     </message>
     <message>
-        <location filename="../autostartpage.ui" line="44"/>
+        <location filename="../autostartpage.ui" line="23"/>
         <source>Application Autostart</source>
         <translation>Puloguramu ezitandikirawo</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="140"/>
-        <location filename="../autostartpage.cpp" line="151"/>
-        <location filename="../autostartpage.cpp" line="170"/>
-        <location filename="../autostartpage.cpp" line="187"/>
+        <location filename="../autostartpage.cpp" line="145"/>
+        <location filename="../autostartpage.cpp" line="156"/>
+        <location filename="../autostartpage.cpp" line="175"/>
+        <location filename="../autostartpage.cpp" line="180"/>
+        <location filename="../autostartpage.cpp" line="197"/>
         <source>Error</source>
         <translation>Kiremya</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="140"/>
-        <location filename="../autostartpage.cpp" line="170"/>
+        <location filename="../autostartpage.cpp" line="175"/>
         <source>Please provide Name and Command</source>
         <translation>Teekawo ekiragiro n&apos;okunnyonyola</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="151"/>
-        <location filename="../autostartpage.cpp" line="187"/>
+        <location filename="../autostartpage.cpp" line="145"/>
+        <location filename="../autostartpage.cpp" line="180"/>
+        <source>Name should not start with dot or contain slash</source>
+        <translation>Erinnya terkkirizibwa okutandika n&apos;akatonyeze era terikkirizibwa okubeeramu akasaze</translation>
+    </message>
+    <message>
+        <location filename="../autostartpage.cpp" line="156"/>
+        <location filename="../autostartpage.cpp" line="197"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>Waliwo fayiro &apos;%1&apos; esangidwawo!</translation>
     </message>
@@ -119,6 +127,7 @@
     </message>
     <message>
         <location filename="../basicsettings.ui" line="49"/>
+        <location filename="../basicsettings.ui" line="226"/>
         <source>Search...</source>
         <translation>Noonya...</translation>
     </message>
@@ -128,12 +137,12 @@
         <translation>Enyingo za LXQt</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="65"/>
+        <location filename="../basicsettings.ui" line="81"/>
         <source>Start</source>
         <translation>Tandika</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="72"/>
+        <location filename="../basicsettings.ui" line="88"/>
         <source>Stop</source>
         <translation>Komya</translation>
     </message>
@@ -178,35 +187,45 @@
         <translation> ms</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="176"/>
+        <location filename="../basicsettings.ui" line="201"/>
+        <source>Use custom screen lock command</source>
+        <translation>Yiiya ekiragiro ekisaanikira olutimbe ekikyo</translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="197"/>
         <source>Select a window manager</source>
         <translation>Londa ekiteekateekamadirisa</translation>
     </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="212"/>
+        <source>Select a screenlocker</source>
+        <translation>Londa puloguramu esaanikira olutimbe</translation>
+    </message>
 </context>
 <context>
     <name>EnvironmentPage</name>
     <message>
-        <location filename="../environmentpage.ui" line="17"/>
+        <location filename="../environmentpage.ui" line="47"/>
         <source>Add</source>
         <translation>Yongerawo</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="24"/>
+        <location filename="../environmentpage.ui" line="54"/>
         <source>Delete</source>
         <translation>Gyawo</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="50"/>
+        <location filename="../environmentpage.ui" line="23"/>
         <source>Environment Variables (Advanced)</source>
         <translation>Bigambo bya mu nviromenti (byetaagisa bumanyirivu)</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="61"/>
+        <location filename="../environmentpage.ui" line="34"/>
         <source>Variable Name</source>
         <translation>Kigambo</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="66"/>
+        <location filename="../environmentpage.ui" line="39"/>
         <source>Value</source>
         <translation>Kye kikongojja</translation>
     </message>
