@@ -65,42 +65,50 @@
 <context>
     <name>AutoStartPage</name>
     <message>
-        <location filename="../autostartpage.ui" line="17"/>
+        <location filename="../autostartpage.ui" line="51"/>
         <source>Delete</source>
         <translation>Sil</translation>
     </message>
     <message>
-        <location filename="../autostartpage.ui" line="24"/>
+        <location filename="../autostartpage.ui" line="37"/>
         <source>Add</source>
         <translation>Ekle</translation>
     </message>
     <message>
-        <location filename="../autostartpage.ui" line="31"/>
+        <location filename="../autostartpage.ui" line="44"/>
         <source>Edit</source>
         <translation>Düzenle</translation>
     </message>
     <message>
-        <location filename="../autostartpage.ui" line="44"/>
+        <location filename="../autostartpage.ui" line="23"/>
         <source>Application Autostart</source>
         <translation>Uygulama Kendiliğinden Çalıştırıcı</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="140"/>
-        <location filename="../autostartpage.cpp" line="151"/>
-        <location filename="../autostartpage.cpp" line="170"/>
-        <location filename="../autostartpage.cpp" line="187"/>
+        <location filename="../autostartpage.cpp" line="145"/>
+        <location filename="../autostartpage.cpp" line="156"/>
+        <location filename="../autostartpage.cpp" line="175"/>
+        <location filename="../autostartpage.cpp" line="180"/>
+        <location filename="../autostartpage.cpp" line="197"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
         <location filename="../autostartpage.cpp" line="140"/>
-        <location filename="../autostartpage.cpp" line="170"/>
+        <location filename="../autostartpage.cpp" line="175"/>
         <source>Please provide Name and Command</source>
         <translation>Lütfen Adını ve Komutu belirtin</translation>
     </message>
     <message>
-        <location filename="../autostartpage.cpp" line="151"/>
-        <location filename="../autostartpage.cpp" line="187"/>
+        <location filename="../autostartpage.cpp" line="145"/>
+        <location filename="../autostartpage.cpp" line="180"/>
+        <source>Name should not start with dot or contain slash</source>
+        <translation>İsim nokta ile başlamamalı veya eğik çizgi içermemelidir</translation>
+    </message>
+    <message>
+        <location filename="../autostartpage.cpp" line="156"/>
+        <location filename="../autostartpage.cpp" line="197"/>
         <source>File &apos;%1&apos; already exists!</source>
         <translation>&apos;%1&apos; dosyası zaten var!</translation>
     </message>
@@ -114,7 +122,7 @@
     </message>
     <message>
         <location filename="../basicsettings.ui" line="49"/>
-        <location filename="../basicsettings.ui" line="213"/>
+        <location filename="../basicsettings.ui" line="226"/>
         <source>Search...</source>
         <translation>Ara...</translation>
     </message>
@@ -166,7 +174,7 @@
     <message>
         <location filename="../basicsettings.ui" line="201"/>
         <source>Use custom screen lock command</source>
-        <translation type="unfinished"></translation>
+        <translation>Özel ekran kilitleme komutu kullan</translation>
     </message>
     <message>
         <location filename="../basicsettings.ui" line="23"/>
@@ -174,12 +182,12 @@
         <translation>Basit Ayarlar</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="65"/>
+        <location filename="../basicsettings.ui" line="81"/>
         <source>Start</source>
         <translation>Başlat</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="72"/>
+        <location filename="../basicsettings.ui" line="88"/>
         <source>Stop</source>
         <translation>Dur</translation>
     </message>
@@ -191,33 +199,33 @@
     <message>
         <location filename="../basicsettings.cpp" line="212"/>
         <source>Select a screenlocker</source>
-        <translation type="unfinished"></translation>
+        <translation>Ekran kilitleyici seç</translation>
     </message>
 </context>
 <context>
     <name>EnvironmentPage</name>
     <message>
-        <location filename="../environmentpage.ui" line="17"/>
+        <location filename="../environmentpage.ui" line="47"/>
         <source>Add</source>
         <translation>Ekle</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="24"/>
+        <location filename="../environmentpage.ui" line="54"/>
         <source>Delete</source>
         <translation>Sil</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="50"/>
+        <location filename="../environmentpage.ui" line="23"/>
         <source>Environment Variables (Advanced)</source>
         <translation>Ortam Değişkenleri (Gelişmiş)</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="61"/>
+        <location filename="../environmentpage.ui" line="34"/>
         <source>Variable Name</source>
         <translation>Değişken Adı</translation>
     </message>
     <message>
-        <location filename="../environmentpage.ui" line="66"/>
+        <location filename="../environmentpage.ui" line="39"/>
         <source>Value</source>
         <translation>Değer</translation>
     </message>
