@@ -28,8 +28,8 @@ class UserLocationsPage : public QWidget {
     Q_OBJECT
 
 public:
-    explicit UserLocationsPage(QWidget *parent = 0);
-    ~UserLocationsPage();
+    explicit UserLocationsPage(QWidget *parent = nullptr);
+    ~UserLocationsPage() override;
 
 Q_SIGNALS:
     void needRestart();
