@@ -47,6 +47,9 @@ public:
     explicit LeaveDialog(QWidget *parent = nullptr);
     ~LeaveDialog() override;
 
+protected:
+    void showEvent(QShowEvent *event) override;
+
 private:
     Ui::LeaveDialog *ui;
     // LXQt::Power is used to know if the actions are doable, while
