@@ -42,12 +42,12 @@ class WmSelectDialog : public QDialog
 
 public:
     explicit WmSelectDialog(const WindowManagerList &availableWindowManagers,
-                            QWidget *parent = 0);
-    ~WmSelectDialog();
+                            QWidget *parent = nullptr);
+    ~WmSelectDialog() override;
     QString windowManager() const;
 
 public slots:
-    void done(int);
+    void done(int) override;
 
 private slots:
     void selectFileDialog(const QModelIndex &index);
